from pkg_resources import resource_filename

processesBtn = resource_filename(
    __name__, "processesBtn.png"
)
yesBtn = resource_filename(
    __name__, "yesBtn.png"
)
plusTab = resource_filename(
    __name__, "plusTab.png"
)
